/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.eos.notificationeditor.service;

import org.apache.felix.ipojo.annotations.Component;
import org.apache.felix.ipojo.annotations.Instantiate;
import org.apache.felix.ipojo.annotations.Invalidate;
import org.apache.felix.ipojo.annotations.Provides;
import org.apache.felix.ipojo.annotations.Requires;
import org.apache.felix.ipojo.annotations.ServiceProperty;
import org.apache.felix.ipojo.annotations.Validate;
import org.ow2.jasmine.monitoring.eos.rules.common.RuleEngineService;
import org.ow2.jasmine.monitoring.eos.rules.common.RuleEngineStatus;
import org.ow2.jasmine.rules.manager.model.IRulePackage;
import org.ow2.jasmine.rules.manager.service.RulePackageCompilationError;
import org.ow2.jasmine.rules.manager.service.RulePackageSaveReport;
import org.ow2.kerneos.core.service.KerneosSimpleService;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;
import org.w3c.dom.Document;

import java.util.List;

/**
 * Notification editor module server-side API
 *
 * @author Julien Nicoulaud
 */
@Component
@Instantiate
@Provides
public class NotificationEditorService implements KerneosSimpleService {

    private static Log logger = LogFactory.getLog(NotificationEditorService.class);

    @ServiceProperty(name = KerneosSimpleService.ID, value = "notificationEditor_ruleEngineService")
    private String id;

    @Requires
    RuleEngineService ruleEngineService;

    public void start(String ruleEngineName) throws Exception {
        ruleEngineService.start(ruleEngineName);
    }

    public void stop(String ruleEngineName) throws Exception {
        ruleEngineService.stop(ruleEngineName);
    }

    public RuleEngineStatus getRuleEngineStatus(String ruleEngineName) throws Exception {
        return ruleEngineService.getRuleEngineStatus(ruleEngineName);
    }

    public List<IRulePackage> getRulePackages(String ruleEngineName) throws Exception {
        return ruleEngineService.getRulePackages(ruleEngineName);
    }

    public IRulePackage getRulePackage(String rulePackageSystemName, String ruleEngineName) throws Exception {
        return ruleEngineService.getRulePackage(rulePackageSystemName, ruleEngineName);
    }

    public List<RulePackageCompilationError> compileRulePackage(IRulePackage rulePackage, String ruleEngineName) throws Exception {
        return ruleEngineService.compileRulePackage(rulePackage, ruleEngineName);
    }

    public void deleteRulePackage(IRulePackage rulePackage, String ruleEngineName) throws Exception {
        ruleEngineService.deleteRulePackage(rulePackage, ruleEngineName);
    }

    public RulePackageSaveReport saveRulePackage(IRulePackage rulePackage, String ruleEngineName) throws Exception {
        return ruleEngineService.saveRulePackage(rulePackage, ruleEngineName);
    }

    public Boolean checkNameAvailability(String systemName, String ruleEngineName) throws Exception {
        return ruleEngineService.checkNameAvailability(systemName, ruleEngineName);
    }

    public IRulePackage importRulePackageFromXML(String filePath, String ruleEngineName) throws Exception {
        return ruleEngineService.importRulePackageFromXML(filePath, ruleEngineName);
    }

    public Document exportRulePackagesAsXML(List<IRulePackage> rulePackages, String ruleEngineName) throws Exception {
        return ruleEngineService.exportRulePackagesAsXML(rulePackages, ruleEngineName);
    }
}
